Skip to main contentModule path
Source - Commands
- An iterator over the commands that make up a path.
- Path
- A sequence of commands that defines a set of contours, each of which consists of a sequence of
curve segments. Each contour is either open or closed.